@@ -1,3 +1,6 @@
+__version__ = '3.5.4'
+__author__ = 'Allan Galarza'
+
 import logging
 
 from tibiapy import abc, enums, utils
@@ -14,10 +17,9 @@ from tibiapy.kill_statistics import *
 from tibiapy.news import *
 from tibiapy.tournament import *
 from tibiapy.world import *
+from tibiapy.bazaar import *
 from tibiapy.client import *
 
-__version__ = '3.2.1'
-
 from logging import NullHandler
 
 logging.getLogger(__name__).addHandler(NullHandler())
