@@ -73,7 +73,7 @@ class Serializable:
         Parameters
         ----------
         indent: :class:`int`, optional
-            Number of spaces used as indentation, ``None`` will return the shortest possible string.
+            Number of spaces used as indentation, :obj:`None` will return the shortest possible string.
         sort_keys: :class:`bool`, optional
             Whether keys should be sorted alphabetically or preserve the order defined by the object.
 
@@ -93,8 +93,8 @@ class BaseAnnouncement(metaclass=abc.ABCMeta):
 
     The following implement this class:
 
-    - :class:`ForumAnnouncement`
-    - :class:`ListedAnnouncement`
+    - :class:`.ForumAnnouncement`
+    - :class:`.ListedAnnouncement`
 
     Attributes
     ----------
@@ -138,8 +138,8 @@ class BaseBoard(metaclass=abc.ABCMeta):
 
     The following implement this class:
 
-    - :class:`ForumBoard`
-    - :class:`ListedBoard`
+    - :class:`.ForumBoard`
+    - :class:`.ListedBoard`
 
     Attributes
     ----------
@@ -242,6 +242,8 @@ class BaseCharacter(metaclass=abc.ABCMeta):
     - :class:`.LeaderboardEntry`
     - :class:`.OnlineCharacter`
     - :class:`.OtherCharacter`
+    - :class:`.ListedAuction`
+    - :class:`.AuctionDetails`
 
     Attributes
     ----------
@@ -509,9 +511,9 @@ class BasePost(metaclass=abc.ABCMeta):
 
     The following implement this class:
 
-    - :class:`CMPost`
-    - :class:`ForumPost`
-    - :class:`LastPost`
+    - :class:`.CMPost`
+    - :class:`.ForumPost`
+    - :class:`.LastPost`
 
     Attributes
     ----------
@@ -568,7 +570,7 @@ class BaseThread(metaclass=abc.ABCMeta):
 
     @property
     def url(self):
-        """:class:`str` The URL to the thread in Tibia.com."""
+        """:class:`str`: The URL to the thread in Tibia.com."""
         return self.get_url(self.thread_id)
 
     @classmethod
