@@ -1,5 +1,7 @@
 import asyncio
 import datetime
+import json
+import logging
 import time
 import typing
 
@@ -7,11 +9,11 @@ import aiohttp
 import aiohttp_socks
 
 import tibiapy
-from tibiapy import abc
+from tibiapy import abc, AuctionDetails, AuctionFilters, CharacterBazaar
 from tibiapy.character import Character
 from tibiapy.creature import BoostedCreature
 from tibiapy.enums import Category, HouseOrder, HouseStatus, HouseType, NewsCategory, NewsType, VocationFilter
-from tibiapy.errors import Forbidden, NetworkError
+from tibiapy.errors import Forbidden, NetworkError, SiteMaintenanceError
 from tibiapy.event import EventSchedule
 from tibiapy.forum import CMPostArchive, ForumAnnouncement, ForumBoard, ForumPost, ForumThread, ListedBoard
 from tibiapy.guild import Guild, GuildWars, ListedGuild
@@ -33,6 +35,7 @@ CACHE_LIMIT = 300
 
 T = typing.TypeVar('T')
 
+log = logging.getLogger("tibiapy")
 
 class TibiaResponse(typing.Generic[T], abc.Serializable):
     """Represents a response from Tibia.com
@@ -150,8 +153,8 @@ class Client:
         else:
             raise NetworkError("Request error, status code: %d" % status_code)
 
-    async def _request(self, method, url, data=None):
-        """Base GET request, handling possible error statuses.
+    async def _request(self, method, url, data=None, headers=None):
+        """Base request, handling possible error statuses.
 
         Parameters
         ----------
@@ -161,6 +164,8 @@ class Client:
             The URL that will be requested.
         data: :class:`dict`
             A mapping representing the form-data to send as part of the request.
+        headers: :class:`dict`
+            A mapping representing the headers to send as part of the request.
 
         Returns
         -------
@@ -178,7 +183,11 @@ class Client:
         await self._session_ready.wait()
         try:
             init_time = time.perf_counter()
-            async with self.session.request(method, url, data=data) as resp:
+            log.info(f"%s | %s | Fetching...", url, method)
+            async with self.session.request(method, url, data=data, headers=headers) as resp:
+                log.info(f"%s | %s | %s %s", url, method, resp.status, resp.reason)
+                if "maintenance.tibia.com" in str(resp.url):
+                    raise SiteMaintenanceError("Tibia.com is down for maintenance.")
                 self._handle_status(resp.status)
                 response = RawResponse(resp, time.perf_counter()-init_time)
                 response.content = await resp.text()
@@ -190,6 +199,176 @@ class Client:
         except UnicodeDecodeError as e:
             raise NetworkError('UnicodeDecodeError: %s' % e, e)
 
+    async def fetch_current_auctions(self, page=1, filters=None):
+        """Fetches the current auctions in the bazaar
+
+        .. versionadded:: 3.3.0
+
+        Parameters
+        ----------
+        page: :class:`int`
+            The desired page to display.
+        filters: :class:`AuctionFilters`
+            The filtering criteria to use.
+
+        Returns
+        -------
+        :class:`TibiaResponse` of :class:`CharacterBazaar`
+            The current auctions.
+
+        Raises
+        ------
+        Forbidden
+            If a 403 Forbidden error was returned.
+            This usually means that Tibia.com is rate-limiting the client because of too many requests.
+        NetworkError
+            If there's any connection errors during the request.
+        ValueError
+            If the page number is not 1 or greater.
+        """
+        if not page:
+            raise ValueError('page must be 1 or greater.')
+        response = await self._request("GET", CharacterBazaar.get_current_auctions_url(page, filters))
+        start_time = time.perf_counter()
+        current_auctions = CharacterBazaar.from_content(response.content)
+        parsing_time = time.perf_counter() - start_time
+        return TibiaResponse(response, current_auctions, parsing_time)
+
+    async def fetch_auction_history(self, page=1):
+        """Fetches the auction history of the bazaar.
+
+        .. versionadded:: 3.3.0
+
+        Parameters
+        ----------
+        page: :class:`int`
+            The page to display.
+
+        Returns
+        -------
+        :class:`TibiaResponse` of :class:`CharacterBazaar`
+            The character bazaar containing the auction history.
+
+        Raises
+        ------
+        Forbidden
+            If a 403 Forbidden error was returned.
+            This usually means that Tibia.com is rate-limiting the client because of too many requests.
+        NetworkError
+            If there's any connection errors during the request.
+        ValueError
+            If the page number is not 1 or greater.
+        """
+        if not page:
+            raise ValueError('page must be 1 or greater.')
+        response = await self._request("GET", CharacterBazaar.get_auctions_history_url(page))
+        start_time = time.perf_counter()
+        auction_history = CharacterBazaar.from_content(response.content)
+        parsing_time = time.perf_counter() - start_time
+        return TibiaResponse(response, auction_history, parsing_time)
+
+    async def fetch_auction(self, auction_id, *, fetch_items=False, fetch_mounts=False, fetch_outfits=False,
+                            skip_details=False):
+        """Fetches an auction by its ID.
+
+        .. versionadded:: 3.3.0
+
+        Parameters
+        ----------
+        auction_id: :class:`int`
+            The ID of the auction.
+        fetch_items: :class:`bool`
+            Whether to fetch all of the character's items. By default only the first page is fetched.
+        fetch_mounts: :class:`bool`
+            Whether to fetch all of the character's mounts. By default only the first page is fetched.
+        fetch_outfits: :class:`bool`
+            Whether to fetch all of the character's outfits. By default only the first page is fetched.
+        skip_details: :class:`bool`, optional
+            Whether to skip parsing the entire auction and only parse the information shown in lists. False by default.
+
+            This allows fetching basic information like name, level, vocation, world, bid and status, shaving off some
+            parsing time.
+
+        Returns
+        -------
+        :class:`TibiaResponse` of :class:`AuctionDetails`
+            The auction matching the ID if found.
+
+        Raises
+        ------
+        Forbidden
+            If a 403 Forbidden error was returned.
+            This usually means that Tibia.com is rate-limiting the client because of too many requests.
+        NetworkError
+            If there's any connection errors during the request.
+        """
+        response = await self._request("GET", AuctionDetails.get_url(auction_id))
+        start_time = time.perf_counter()
+        auction = AuctionDetails.from_content(response.content, auction_id, skip_details)
+        parsing_time = time.perf_counter() - start_time
+        if auction and not skip_details:
+            if fetch_items:
+                await self._fetch_all_pages(auction_id, auction.items, 0)
+                await self._fetch_all_pages(auction_id, auction.store_items, 1)
+            if fetch_mounts:
+                await self._fetch_all_pages(auction_id, auction.mounts, 2)
+                await self._fetch_all_pages(auction_id, auction.store_mounts, 3)
+            if fetch_outfits:
+                await self._fetch_all_pages(auction_id, auction.outfits, 4)
+                await self._fetch_all_pages(auction_id, auction.store_outfits, 5)
+        return TibiaResponse(response, auction, parsing_time)
+
+    async def _fetch_all_pages(self, auction_id, paginator, item_type):
+        """Fetches all the pages of a auction paginator.
+
+        Parameters
+        ----------
+        auction_id: :class:`int`
+            The id of the auction.
+        paginator:
+            The paginator object
+        item_type: :class:`int`
+            The item type.
+        """
+        if paginator is None or paginator.entry_class is None:
+            return
+        current_page = 2
+        while current_page <= paginator.total_pages:
+            content = await self._fetch_ajax_page(auction_id, item_type, current_page)
+            entries = AuctionDetails.parse_page_items(content, paginator.entry_class)
+            paginator.entries.extend(entries)
+            current_page += 1
+        paginator.fully_fetched = True
+
+    async def _fetch_ajax_page(self, auction_id, type_id, page):
+        """Fetches an ajax page from the paginated summaries in the auction section.
+
+        Parameters
+        ----------
+        auction_id: :class:`int`
+            The id of the auction.
+        type_id: :class:`int`
+            The ID of the type of the catalog to check.
+        page: :class:`int`
+            The page number to fetch.
+
+        Returns
+        -------
+        :class:`str`:
+            The HTML content of the obtained page.
+        """
+        headers = {"x-requested-with": "XMLHttpRequest"}
+        page_response = await self._request("GET", f"https://www.tibia.com/charactertrade/ajax_getcharacterdata.php?"
+                                                   f"auctionid={auction_id}&"
+                                                   f"type={type_id}&"
+                                                   f"currentpage={page}",
+                                            headers=headers)
+        data = json.loads(page_response.content)
+        try:
+            return data['AjaxObjects'][0]['Data']
+        except KeyError:
+            return None
+
     async def fetch_cm_post_archive(self, start_date, end_date, page=1):
         """Fetches the CM post archive.
 
@@ -223,7 +402,7 @@ class Client:
             raise ValueError("start_date cannot be more recent than end_date")
         if page <= 0:
             raise ValueError("page cannot be lower than 1.")
-        response = await self._request("get", CMPostArchive.get_url(start_date, end_date, page))
+        response = await self._request("GET", CMPostArchive.get_url(start_date, end_date, page))
         start_time = time.perf_counter()
         cm_post_archive = CMPostArchive.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -256,7 +435,7 @@ class Client:
         """
         if (year is None and month is not None) or (year is not None and month is None):
             raise ValueError("both year and month must be defined or neither must be defined.")
-        response = await self._request("get", EventSchedule.get_url(month, year))
+        response = await self._request("GET", EventSchedule.get_url(month, year))
         start_time = time.perf_counter()
         calendar = EventSchedule.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -280,7 +459,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", ListedBoard.get_community_boards_url())
+        response = await self._request("GET", ListedBoard.get_community_boards_url())
         start_time = time.perf_counter()
         boards = ListedBoard.list_from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -303,7 +482,7 @@ class Client:
             This usually means that Tibia.com is rate-limiting the client because of too many requests.
         NetworkError
             If there's any connection errors during the request."""
-        response = await self._request("get", ListedBoard.get_support_boards_url())
+        response = await self._request("GET", ListedBoard.get_support_boards_url())
         start_time = time.perf_counter()
         boards = ListedBoard.list_from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -326,7 +505,7 @@ class Client:
             This usually means that Tibia.com is rate-limiting the client because of too many requests.
         NetworkError
             If there's any connection errors during the request."""
-        response = await self._request("get", ListedBoard.get_world_boards_url())
+        response = await self._request("GET", ListedBoard.get_world_boards_url())
         start_time = time.perf_counter()
         boards = ListedBoard.list_from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -349,7 +528,7 @@ class Client:
             This usually means that Tibia.com is rate-limiting the client because of too many requests.
         NetworkError
             If there's any connection errors during the request."""
-        response = await self._request("get", ListedBoard.get_trade_boards_url())
+        response = await self._request("GET", ListedBoard.get_trade_boards_url())
         start_time = time.perf_counter()
         boards = ListedBoard.list_from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -383,7 +562,7 @@ class Client:
             This usually means that Tibia.com is rate-limiting the client because of too many requests.
         NetworkError
             If there's any connection errors during the request."""
-        response = await self._request("get", ForumBoard.get_url(board_id, page, age))
+        response = await self._request("GET", ForumBoard.get_url(board_id, page, age))
         start_time = time.perf_counter()
         board = ForumBoard.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -413,7 +592,7 @@ class Client:
             This usually means that Tibia.com is rate-limiting the client because of too many requests.
         NetworkError
             If there's any connection errors during the request."""
-        response = await self._request("get", ForumThread.get_url(thread_id, page))
+        response = await self._request("GET", ForumThread.get_url(thread_id, page))
         start_time = time.perf_counter()
         thread = ForumThread.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -446,7 +625,7 @@ class Client:
             This usually means that Tibia.com is rate-limiting the client because of too many requests.
         NetworkError
             If there's any connection errors during the request."""
-        response = await self._request("get", ForumPost.get_url(post_id))
+        response = await self._request("GET", ForumPost.get_url(post_id))
         start_time = time.perf_counter()
         thread = ForumThread.from_content(response.content)
         if thread:
@@ -477,7 +656,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", ForumAnnouncement.get_url(announcement_id))
+        response = await self._request("GET", ForumAnnouncement.get_url(announcement_id))
         start_time = time.perf_counter()
         announcement = ForumAnnouncement.from_content(response.content, announcement_id)
         parsing_time = time.perf_counter() - start_time
@@ -501,7 +680,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", News.get_list_url())
+        response = await self._request("GET", News.get_list_url())
         start_time = time.perf_counter()
         boosted_creature = BoostedCreature.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -528,7 +707,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", Character.get_url(name.strip()))
+        response = await self._request("GET", Character.get_url(name.strip()))
         start_time = time.perf_counter()
         char = Character.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -555,7 +734,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", Guild.get_url(name))
+        response = await self._request("GET", Guild.get_url(name))
         start_time = time.perf_counter()
         guild = Guild.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -587,7 +766,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", GuildWars.get_url(name))
+        response = await self._request("GET", GuildWars.get_url(name))
         start_time = time.perf_counter()
         guild_wars = GuildWars.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -606,7 +785,7 @@ class Client:
         Returns
         -------
         :class:`TibiaResponse` of :class:`House`
-            The house if found, ``None`` otherwise.
+            The house if found, :obj:`None` otherwise.
 
         Raises
         ------
@@ -616,7 +795,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", House.get_url(house_id, world))
+        response = await self._request("GET", House.get_url(house_id, world))
         start_time = time.perf_counter()
         house = House.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -640,7 +819,7 @@ class Client:
         Returns
         -------
         :class:`TibiaResponse` of :class:`Highscores`
-            The highscores information or ``None`` if not found.
+            The highscores information or :obj:`None` if not found.
 
         Raises
         ------
@@ -650,7 +829,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", Highscores.get_url(world, category, vocation, page))
+        response = await self._request("GET", Highscores.get_url(world, category, vocation, page))
         start_time = time.perf_counter()
         highscores = Highscores.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -677,7 +856,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", KillStatistics.get_url(world))
+        response = await self._request("GET", KillStatistics.get_url(world))
         start_time = time.perf_counter()
         kill_statistics = KillStatistics.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -694,7 +873,7 @@ class Client:
         Returns
         -------
         :class:`TibiaResponse` of :class:`World`
-            A response containig the he world's information if found, ```None`` otherwise.
+            A response containig the he world's information if found, :obj:`None` otherwise.
 
         Raises
         ------
@@ -704,7 +883,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", World.get_url(name))
+        response = await self._request("GET", World.get_url(name))
         start_time = time.perf_counter()
         world = World.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -740,7 +919,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", ListedHouse.get_list_url(world, town, house_type, status, order))
+        response = await self._request("GET", ListedHouse.get_list_url(world, town, house_type, status, order))
         start_time = time.perf_counter()
         world_houses = ListedHouse.list_from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -767,7 +946,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", ListedGuild.get_world_list_url(world))
+        response = await self._request("GET", ListedGuild.get_world_list_url(world))
         start_time = time.perf_counter()
         guilds = ListedGuild.list_from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -789,7 +968,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", WorldOverview.get_url())
+        response = await self._request("GET", WorldOverview.get_url())
         start_time = time.perf_counter()
         world_overview = WorldOverview.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -896,7 +1075,7 @@ class Client:
         Returns
         -------
         :class:`TibiaResponse` of :class:`News`
-            The news entry if found, ``None`` otherwise.
+            The news entry if found, :obj:`None` otherwise.
 
         Raises
         ------
@@ -906,7 +1085,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", News.get_url(news_id))
+        response = await self._request("GET", News.get_url(news_id))
         start_time = time.perf_counter()
         news = News.from_content(response.content, news_id)
         parsing_time = time.perf_counter() - start_time
@@ -925,7 +1104,7 @@ class Client:
         Returns
         -------
         :class:`TibiaResponse` of :class:`Tournament`
-            The tournament if found, ``None`` otherwise.
+            The tournament if found, :obj:`None` otherwise.
 
         Raises
         ------
@@ -935,7 +1114,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", Tournament.get_url(tournament_cycle))
+        response = await self._request("GET", Tournament.get_url(tournament_cycle))
         start_time = time.perf_counter()
         tournament = Tournament.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
@@ -958,7 +1137,7 @@ class Client:
         Returns
         -------
         :class:`TibiaResponse` of :class:`TournamentLeaderboard`
-            The tournament's leaderboard if found, ``None`` otherwise.
+            The tournament's leaderboard if found, :obj:`None` otherwise.
 
         Raises
         ------
@@ -968,7 +1147,7 @@ class Client:
         NetworkError
             If there's any connection errors during the request.
         """
-        response = await self._request("get", TournamentLeaderboard.get_url(world, tournament_cycle, page))
+        response = await self._request("GET", TournamentLeaderboard.get_url(world, tournament_cycle, page))
         start_time = time.perf_counter()
         tournament_leaderboard = TournamentLeaderboard.from_content(response.content)
         parsing_time = time.perf_counter() - start_time
